==> Evergreen-ILS-3.14.7.tar.gz: Evergreen-ILS-3.14.7/Open-ILS/web/js/dojo/openils/actor/nls/ru-ru/register.js <==
{
    ":DEFAULT_ADDRESS_TYPE": "\u041f\u041e\u0427\u0422\u041e\u0412\u042b\u0419",
    ":DELETE_ADDRESS": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c \u0430\u0434\u0440\u0435\u0441 ${0}?",
    ":NEED_ADDRESS": "\u041f\u0440\u0438 \u0440\u0435\u0433\u0438\u0441\u0442\u0440\u0430\u0446\u0438\u0438 \u0442\u0440\u0435\u0431\u0443\u0435\u0442\u0441\u044f \u0430\u0434\u0440\u0435\u0441",
    ":DUPE_PATRON_NAME": "\u041d\u0430\u0439\u0434\u0435\u043d(\u043e) ${0} \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c(\u044f.\u0435\u0439) \u0441 \u0442\u0430\u043a\u0438\u043c \u0436\u0435 \u0438\u043c\u0435\u043d\u0435\u043c",
    ":DUPE_PATRON_EMAIL": "\u041d\u0430\u0439\u0434\u0435\u043d\u043e ${0} \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c(\u044f,\u0435\u0439) \u0441 \u0442\u0430\u043a\u0438\u043c \u0436\u0435 \u0430\u0434\u0440\u0435\u0441\u043e\u043c \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u044b",
    ":DUPE_PATRON_IDENT": "\u041d\u0430\u0439\u0434\u0435\u043d(\u043e) ${0} \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c(\u044f,\u0435\u0439) \u0441 \u0442\u0430\u043a\u0438\u043c \u0436\u0435 \u0438\u0434\u0435\u043d\u0442\u0438\u0444\u0438\u043a\u0430\u0442\u043e\u0440\u043e\u043c",
    ":DUPE_PATRON_PHONE": "\u041d\u0430\u0439\u0434\u0435\u043d(\u043e) ${0} \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c(\u044f,\u0435\u0439) \u0441 \u0442\u0430\u043a\u0438\u043c \u0436\u0435 \u043d\u043e\u043c\u0435\u0440\u043e\u043c \u0442\u0435\u043b\u0435\u0444\u043e\u043d\u0430",
    ":DUPE_PATRON_ADDR": "\u041d\u0430\u0439\u0434\u0435\u043d\u043e $ {0} \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c(\u044f,\u0435\u0439) \u0441 \u0442\u0430\u043a\u0438\u043c \u0436\u0435 \u0430\u0434\u0440\u0435\u0441\u043e\u043c",
    ":REPLACED_ADDRESS": "Replaces address ${0}<br/> ${1} ${2}<br/> ${3}, ${4} ${5}",
    ":INVALID_FORM": "\u0424\u043e\u0440\u043c\u0430 \u044f\u0432\u043b\u044f\u0435\u0442\u0441\u044f \u043d\u0435\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u043e\u0439. \u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0440\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u0443\u0439\u0442\u0435 \u0438 \u043f\u043e\u043f\u0440\u043e\u0431\u0443\u0439\u0442\u0435 \u0435\u0449\u0435 \u0440\u0430\u0437.",
    ":EXAMPLE": "\u041d\u0430\u043f\u0440\u0438\u043c\u0435\u0440: ",
    ":REPLACE_BARCODE": "\u0417\u0430\u043c\u0435\u043d\u0438\u0442\u0435 \u0448\u0442\u0440\u0438\u0445-\u043a\u043e\u0434",
    ":BARCODE_IN_USE": "\u0428\u0442\u0440\u0438\u0445-\u043a\u043e\u0434 \u0443\u0436\u0435 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f",
    ":SEE_ALL": "\u0421\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u0432\u0441\u0435",
    ":DUPE_USERNAME": "\u0418\u043c\u044f \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044f \u0443\u0436\u0435 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f",
    ":RESET_PASSWORD": "Generate Password",
    ":VERIFY_PASSWORD": "\u041f\u0440\u043e\u0432\u0435\u0440\u0438\u0442\u044c \u043f\u0430\u0440\u043e\u043b\u044c",
    ":PARENT_OR_GUARDIAN": "\u0420\u043e\u0434\u0438\u0442\u0435\u043b\u044c/\u041e\u043f\u0435\u043a\u0443\u043d",
    ":USER_SETTINGS": "\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438 \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044f",
    ":ADDRESS_HEADER": "\u041f\u043e\u0447\u0442\u043e\u0432\u044b\u0439 \u0430\u0434\u0440\u0435\u0441",
    ":ADDRESS_MAILING": "\u0420\u0430\u0441\u0441\u044b\u043b\u043a\u0430",
    ":ADDRESS_BILLING": "\u0421\u0447\u0435\u0442",
    ":ADDRESS_PENDING": "This is a pending address: ",
    ":ADDRESS_APPROVE": "\u041f\u043e\u0432\u0442\u043e\u0440\u0438\u0442\u044c \u0430\u0434\u0440\u0435\u0441",
    ":ADDRESS_OWNED": "\u042d\u0442\u043e\u0442 \u0430\u0434\u0440\u0435\u0441 \u043f\u0440\u0438\u043d\u0430\u0434\u043b\u0435\u0436\u0438\u0442 \u0434\u0440\u0443\u0433\u043e\u043c\u0443 \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044e: ",
    ":ADDRESS_NEW": "\u041d\u043e\u0432\u044b\u0439 \u0430\u0434\u0440\u0435\u0441",
    ":STAT_CATS": "\u0421\u0442\u0430\u0442\u0438\u0441\u0442\u0438\u0447\u0435\u0441\u043a\u0438\u0435 \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438",
    ":SAVE": "\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c",
    ":SAVE_CLONE": "Save &amp; Clone",
    ":SHOW_REQUIRED": "\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u044c \u0442\u043e\u043b\u044c\u043a\u043e \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u044b\u0435 \u0434\u043b\u044f \u0437\u0430\u043f\u043e\u043b\u043d\u0435\u043d\u0438\u044f \u043f\u043e\u043b\u044f",
    ":SHOW_SUGGESTED": "Show Suggested Fields",
    ":SHOW_ALL": "\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u044c \u0432\u0441\u0435 \u043f\u043e\u043b\u044f",
    ":ALL_CARDS_BARCODE": "Barcode",
    ":ALL_CARDS_ACTIVE": "Active",
    ":ALL_CARDS_PRIMARY": "Primary",
    ":ALL_CARDS_CLOSE": "Close",
    ":ALL_CARDS_APPLY": "Apply Changes",
    ":INVALIDATE": "Invalidate",
    ":HOLD_NOTIFY_PHONE": "Phone: ",
    ":HOLD_NOTIFY_EMAIL": "Email: ",
    ":HOLD_NOTIFY_SMS": "SMS: ",
    ":REQUESTING_USER": "Account requested by ${0} ${1}",
    ":UPDATE_EXPIRE_DATE": "Update Expire Date",
    ":DELETE": "Delete",
    ":ADD": "Add",
    ":SECONDARY_GROUP_NOT_ALLOWED": "You do not have permission to add this group.",
    ":SECONDARY_GROUP_IS_PROFILE": "That is already the primary profile group for this patron.",
    ":SECONDARY_GROUP_EXISTS": "This group is on the list already.",
    ":SECONDARY_GROUP_ERROR": "Error saving secondary groups."
}

==> Evergreen-ILS-3.16.1.tar.gz: Evergreen-ILS-3.16.1/Open-ILS/web/js/dojo/openils/actor/nls/ru-ru/register.js <==
{
    ":DEFAULT_ADDRESS_TYPE": "\u041f\u041e\u0427\u0422\u041e\u0412\u042b\u0419",
    ":DELETE_ADDRESS": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c \u0430\u0434\u0440\u0435\u0441 ${0}?",
    ":NEED_ADDRESS": "\u041f\u0440\u0438 \u0440\u0435\u0433\u0438\u0441\u0442\u0440\u0430\u0446\u0438\u0438 \u0442\u0440\u0435\u0431\u0443\u0435\u0442\u0441\u044f \u0430\u0434\u0440\u0435\u0441",
    ":DUPE_PATRON_NAME": "\u041d\u0430\u0439\u0434\u0435\u043d(\u043e) ${0} \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c(\u044f.\u0435\u0439) \u0441 \u0442\u0430\u043a\u0438\u043c \u0436\u0435 \u0438\u043c\u0435\u043d\u0435\u043c",
    ":DUPE_PATRON_EMAIL": "\u041d\u0430\u0439\u0434\u0435\u043d\u043e ${0} \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c(\u044f,\u0435\u0439) \u0441 \u0442\u0430\u043a\u0438\u043c \u0436\u0435 \u0430\u0434\u0440\u0435\u0441\u043e\u043c \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u044b",
    ":DUPE_PATRON_IDENT": "\u041d\u0430\u0439\u0434\u0435\u043d(\u043e) ${0} \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c(\u044f,\u0435\u0439) \u0441 \u0442\u0430\u043a\u0438\u043c \u0436\u0435 \u0438\u0434\u0435\u043d\u0442\u0438\u0444\u0438\u043a\u0430\u0442\u043e\u0440\u043e\u043c",
    ":DUPE_PATRON_PHONE": "\u041d\u0430\u0439\u0434\u0435\u043d(\u043e) ${0} \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c(\u044f,\u0435\u0439) \u0441 \u0442\u0430\u043a\u0438\u043c \u0436\u0435 \u043d\u043e\u043c\u0435\u0440\u043e\u043c \u0442\u0435\u043b\u0435\u0444\u043e\u043d\u0430",
    ":DUPE_PATRON_ADDR": "\u041d\u0430\u0439\u0434\u0435\u043d\u043e $ {0} \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c(\u044f,\u0435\u0439) \u0441 \u0442\u0430\u043a\u0438\u043c \u0436\u0435 \u0430\u0434\u0440\u0435\u0441\u043e\u043c",
    ":REPLACED_ADDRESS": "<div>\u0417\u0430\u043c\u0435\u043d\u044f\u0435\u0442 \u0430\u0434\u0440\u0435\u0441 <b>${0}</b><br/> ${1} ${2}<br/> ${3}, ${4} ${5}</div>",
    ":INVALID_FORM": "\u0424\u043e\u0440\u043c\u0430 \u044f\u0432\u043b\u044f\u0435\u0442\u0441\u044f \u043d\u0435\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u043e\u0439. \u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0440\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u0443\u0439\u0442\u0435 \u0438 \u043f\u043e\u043f\u0440\u043e\u0431\u0443\u0439\u0442\u0435 \u0435\u0449\u0435 \u0440\u0430\u0437.",
    ":EXAMPLE": "\u041d\u0430\u043f\u0440\u0438\u043c\u0435\u0440: ",
    ":REPLACE_BARCODE": "\u0417\u0430\u043c\u0435\u043d\u0438\u0442\u0435 \u0448\u0442\u0440\u0438\u0445-\u043a\u043e\u0434",
    ":BARCODE_IN_USE": "\u0428\u0442\u0440\u0438\u0445-\u043a\u043e\u0434 \u0443\u0436\u0435 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f",
    ":SEE_ALL": "\u0421\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u0432\u0441\u0435",
    ":DUPE_USERNAME": "\u0418\u043c\u044f \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044f \u0443\u0436\u0435 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f",
    ":RESET_PASSWORD": "Generate Password",
    ":VERIFY_PASSWORD": "\u041f\u0440\u043e\u0432\u0435\u0440\u0438\u0442\u044c \u043f\u0430\u0440\u043e\u043b\u044c",
    ":PARENT_OR_GUARDIAN": "\u0420\u043e\u0434\u0438\u0442\u0435\u043b\u044c/\u041e\u043f\u0435\u043a\u0443\u043d",
    ":PARENT_OR_GUARDIAN_EMAIL": "Parent/Guardian Email",
    ":USER_SETTINGS": "\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438 \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044f",
    ":ADDRESS_HEADER": "\u041f\u043e\u0447\u0442\u043e\u0432\u044b\u0439 \u0430\u0434\u0440\u0435\u0441",
    ":ADDRESS_MAILING": "\u0420\u0430\u0441\u0441\u044b\u043b\u043a\u0430",
    ":ADDRESS_BILLING": "\u0421\u0447\u0435\u0442",
    ":ADDRESS_PENDING": "This is a pending address: ",
    ":ADDRESS_APPROVE": "\u041f\u043e\u0432\u0442\u043e\u0440\u0438\u0442\u044c \u0430\u0434\u0440\u0435\u0441",
    ":ADDRESS_OWNED": "\u042d\u0442\u043e\u0442 \u0430\u0434\u0440\u0435\u0441 \u043f\u0440\u0438\u043d\u0430\u0434\u043b\u0435\u0436\u0438\u0442 \u0434\u0440\u0443\u0433\u043e\u043c\u0443 \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044e: ",
    ":ADDRESS_NEW": "\u041d\u043e\u0432\u044b\u0439 \u0430\u0434\u0440\u0435\u0441",
    ":STAT_CATS": "\u0421\u0442\u0430\u0442\u0438\u0441\u0442\u0438\u0447\u0435\u0441\u043a\u0438\u0435 \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438",
    ":SAVE": "\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c",
    ":SAVE_CLONE": "Save &amp; Clone",
    ":SHOW_REQUIRED": "\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u044c \u0442\u043e\u043b\u044c\u043a\u043e \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u044b\u0435 \u0434\u043b\u044f \u0437\u0430\u043f\u043e\u043b\u043d\u0435\u043d\u0438\u044f \u043f\u043e\u043b\u044f",
    ":SHOW_SUGGESTED": "Show Suggested Fields",
    ":SHOW_ALL": "\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u044c \u0432\u0441\u0435 \u043f\u043e\u043b\u044f",
    ":ALL_CARDS_BARCODE": "Barcode",
    ":ALL_CARDS_ACTIVE": "Active",
    ":ALL_CARDS_PRIMARY": "Primary",
    ":ALL_CARDS_CLOSE": "Close",
    ":ALL_CARDS_APPLY": "Apply Changes",
    ":INVALIDATE": "Invalidate",
    ":HOLD_NOTIFY_PHONE": "Phone: ",
    ":HOLD_NOTIFY_EMAIL": "Email: ",
    ":HOLD_NOTIFY_SMS": "SMS: ",
    ":REQUESTING_USER": "Account requested by ${0} ${1}",
    ":UPDATE_EXPIRE_DATE": "Update Expire Date",
    ":DELETE": "Delete",
    ":ADD": "Add",
    ":SECONDARY_GROUP_NOT_ALLOWED": "You do not have permission to add this group.",
    ":SECONDARY_GROUP_IS_PROFILE": "That is already the primary profile group for this patron.",
    ":SECONDARY_GROUP_EXISTS": "This group is on the list already.",
    ":SECONDARY_GROUP_ERROR": "Error saving secondary groups."
}
